| Title: | Raw, Central and Standardized Moments of Parametric Distributions |
|---|---|
| Description: | To calculate the raw, central and standardized moments from distribution parameters. To solve the distribution parameters based on user-provided mean, standard deviation, skewness and kurtosis. Normal, skew-normal, skew-t and Tukey g-&-h distributions are supported, for now. |
| Authors: | Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>) |
| Maintainer: | Tingting Zhan <[email protected]> |
| License: | GPL-2 |
| Version: | 0.2.0 |
| Built: | 2026-05-31 06:12:26 UTC |
| Source: | https://github.com/tingtingzhan/param2moment |
..
distnamecharacter scalar, name of distribution,
e.g., 'norm' for normal, 'sn' for skew-normal, 'st' for skew-,
and 'GH' for Tukey -&- distribution,
following the nomenclature of dnorm, dsn, dst and QuantileGH::dGH
location,scaleraw1,raw2,raw3,raw4central2,central3,central4numeric scalars or vectors, 2nd or higher order central moments
standardized3,standardized4numeric scalars or vectors, 3rd or higher standardized moments
Potential name clash with function e1071::moment.